@@ -95,9 +95,18 @@ vimp_regression <- function(Y, X, f1 = NULL, f2 = NULL, indx = 1, run_regression
     ## get the fitted values
     fhat_ful <- SuperLearner::predict.SuperLearner(full)$pred
 
-    ## fit the reduced data regression
-    reduced <- SuperLearner::SuperLearner(fhat_ful, X = X_minus_s, SL.library = SL.library,...)
-    
+    ## fit the super learner on the reduced covariates:
+    ## always use gaussian; if first regression was mean, use Y instead
+    arg_lst <- list(...)
+    if (length(unique(fhat_ful)) == 1) {
+        arg_lst$Y <- Y
+    } else {
+        arg_lst$family <- stats::gaussian()
+        arg_lst$Y <- fhat_ful 
+    }
+    arg_lst$X <- X_minus_s
+    arg_lst$SL.library <- SL.library
+    reduced <- do.call(SuperLearner::SuperLearner, arg_lst)    
 
     ## get the fitted values
     fhat_red <- SuperLearner::predict.SuperLearner(reduced)$pred
